@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 import argparse
 import http.client as httplib
-import sys
 import shutil
+import sys
 import textwrap
 from typing import Iterable, List, Optional, Set
 
@@ -78,7 +78,10 @@ def parse_args(args_list: Optional[List[str]] = None) -> argparse.Namespace:
         help="Set a retry limit on failed save.",
     )
     parser.add_argument(
-        "-t", "--only_target", action="store_true", help="Save just same domain of target"
+        "-t",
+        "--only_target",
+        action="store_true",
+        help="Save just same domain of target",
     )
     parser.add_argument(
         "-l",
